# Comparison of execution time with sklearn's PCA

As we can see below the PyTorch PCA is faster than sklearn's PCA, in all the
configs tested with the parameter by default (for each PCA model):

![include](https://raw.githubusercontent.com/valentingol/torch_pca/main/docs/_static/comparison.png)
